@@ -23,38 +23,36 @@
 #include <Models/EmMixtureComponent.hpp>
 #include <Models/Policies/ParamPolicy_1.hpp>
 #include <Models/Policies/SufstatDataPolicy.hpp>
-#include <Models/Policies/ConjugatePriorPolicy.hpp>
+#include <Models/Policies/PriorPolicy.hpp>
 
 namespace BOOM{
 
-  class BetaBinomialSampler;
-
   class BinomialSuf : public SufstatDetails<IntData>{
   public:
     BinomialSuf();
     BinomialSuf(const BinomialSuf &rhs);
-    BinomialSuf * clone()const;
+    BinomialSuf * clone()const override;
     void set(double sum, double observation_count);
 
     double sum()const;
     double nobs()const;
-    virtual void clear();
-    virtual void Update(const IntData &);
+    void clear() override;
+    void Update(const IntData &) override;
     void update_raw(double y);
     void batch_update(double n, double y);
 
     void add_mixture_data(double y, double prob);
 
-    BinomialSuf * abstract_combine(Sufstat *s);
+    BinomialSuf * abstract_combine(Sufstat *s) override;
     void combine(Ptr<BinomialSuf>);
     void combine(const BinomialSuf &);
 
-    virtual Vec vectorize(bool minimal=true)const;
-    virtual Vec::const_iterator unvectorize(Vec::const_iterator &v,
-					    bool minimal=true);
-    virtual Vec::const_iterator unvectorize(const Vec &v,
-					    bool minimal=true);
-    virtual ostream &print(ostream &out)const;
+    Vector vectorize(bool minimal=true)const override;
+    Vector::const_iterator unvectorize(Vector::const_iterator &v,
+                                            bool minimal=true) override;
+    Vector::const_iterator unvectorize(const Vector &v,
+                                            bool minimal=true) override;
+    ostream &print(ostream &out)const override;
   private:
     double sum_, nobs_;
   };
@@ -62,42 +60,37 @@ namespace BOOM{
   class BinomialModel
     : public ParamPolicy_1<UnivParams>,
       public SufstatDataPolicy<IntData,BinomialSuf>,
-      public ConjugatePriorPolicy<BetaBinomialSampler>,
+      public PriorPolicy,
       public NumOptModel,
       public EmMixtureComponent
   {
   public:
     BinomialModel(uint n=1, double p=.5);
     BinomialModel(const BinomialModel &rhs);
-    BinomialModel * clone()const;
+    BinomialModel * clone()const override;
 
-    virtual void mle();
-    virtual double Loglike(
-        const Vector &probvec, Vec &g, Mat &h, uint nd)const;
+    void mle() override;
+    double Loglike(
+        const Vector &probvec, Vector &g, Matrix &h, uint nd)const override;
 
     uint n()const;
     double prob()const;
     void set_prob(double p);
 
     virtual double pdf(Ptr<Data> x, bool logscale)const;
-    virtual double pdf(const Data * x, bool logscale)const;
+    double pdf(const Data * x, bool logscale)const override;
     double pdf(uint x, bool logscale)const;
 
     Ptr<UnivParams> Prob_prm();
     const Ptr<UnivParams> Prob_prm()const;
     uint sim()const;
 
-    virtual void find_posterior_mode();
-    virtual void add_mixture_data(Ptr<Data>, double prob);
+    void add_mixture_data(Ptr<Data>, double prob) override;
 
-    // Sets the prior distribution to a Beta(a, b), and sets the prior
-    // sampler to a BetaBinomialSampler.
-    void set_conjugate_prior(double a, double b);
-    void set_conjugate_prior(Ptr<BetaBinomialSampler>);
   private:
     const uint n_;
   };
 
-}
+}  // namespace BOOM
 
 #endif // BOOM_BINOMIAL_MODEL_HPP
