@@ -20,7 +20,6 @@
 
 #include <TargetFun/TargetFun.hpp>
 #include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <boost/function.hpp>
 #include <Models/ParamTypes.hpp>
 
 namespace BOOM{
@@ -34,7 +33,6 @@ namespace BOOM{
       : public BOOM::TargetFun{
     public:
       SubjectTF(Ptr<Subject>, Ptr<SubjectPrior>);
-      //      SubjectTF * clone()const{return new SubjectTF(*this);}
       double operator()(const Vector &v)const override;
     private:
       Ptr<Subject> sub;
@@ -43,7 +41,6 @@ namespace BOOM{
       mutable Vector wsp;
     };
 
-
     class SubjectSliceSampler
       : public PosteriorSampler{
     public:
@@ -59,8 +56,6 @@ namespace BOOM{
       Ptr<SliceSampler> sam;
       Vector Theta;
     };
-
-
-  }
-}
+  }  // namespace IRT
+}  // namespace BOOM
 #endif // BOOM_IRT_SUBJECT_SLICE_SAMPLER_HPP
