@@ -39,10 +39,11 @@ namespace BOOM{
       public PriorPolicy,
       public LatentVariableModel,
       public LoglikeModel,
-      public LocationScaleVectorModel
+      public LocationScaleVectorModel,
+      public MixtureComponent
   {
   public:
-    MvtModel(uint p, double mu=0.0, double sig=1.0, double nu =30.0);
+    MvtModel(uint p, double mu = 0.0, double sig = 1.0, double nu = 30.0);
     MvtModel(const Vector &mean, const SpdMatrix &Var, double Nu);
     MvtModel(const MvtModel &m);
 
@@ -54,47 +55,47 @@ namespace BOOM{
     Ptr<SpdParams> Sigma_prm();
     Ptr<UnivParams> Nu_prm();
 
-    const Ptr<VectorParams> Mu_prm()const;
-    const Ptr<SpdParams> Sigma_prm()const;
-    const Ptr<UnivParams> Nu_prm()const;
+    const Ptr<VectorParams> Mu_prm() const;
+    const Ptr<SpdParams> Sigma_prm() const;
+    const Ptr<UnivParams> Nu_prm() const;
 
-    int dim()const;
-    const Vector &mu()const override;
-    const SpdMatrix &Sigma()const override;
-    const SpdMatrix &siginv()const override;
-    const Matrix &Sigma_chol()const;
-    double ldsi()const override;
+    int dim() const;
+    const Vector &mu() const override;
+    const SpdMatrix &Sigma() const override;
+    const SpdMatrix &siginv() const override;
+    const Matrix &Sigma_chol() const;
+    double ldsi() const override;
     double nu() const;
 
-    void set_mu(const Vector &) override;
-    void set_Sigma(const SpdMatrix &) override;
-    void set_siginv(const SpdMatrix &) override;
-    void set_S_Rchol(const Vector &S, const Matrix &L) override;
+    void set_mu(const Vector &);
+    void set_Sigma(const SpdMatrix &);
+    void set_siginv(const SpdMatrix &);
     void set_nu(double);
 
-    double logp(const Vector &x)const override;
+    double logp(const Vector &x) const override;
 
-    double pdf(Ptr<VectorData>, bool logscale)const;
-    double pdf(dPtr dp, bool logscale) const;
+    double pdf(const Data *dp, bool logscale) const override;
+    double pdf(const VectorData *dp, bool logscale) const;
     double pdf(const Vector &x, bool logscale) const;
 
     void add_data(Ptr<Data>) override;
     void add_data(Ptr<VectorData>) override;
 
     void mle() override;  // ECME
-    double loglike(const Vector &mu_siginv_triangle_nu)const override;
+    double loglike(const Vector &mu_siginv_triangle_nu) const override;
     void impute_latent_data(RNG &rng) override;
     void Estep();  // E step for EM/ECME
 
-    virtual double complete_data_loglike()const;
-    Vector sim()const override;
-    Vector sim(RNG &rng)const;
+    virtual double complete_data_loglike() const;
+    Vector sim() const override;
+    Vector sim(RNG &rng) const;
+
   private:
     void Impute(bool sample, RNG &rng = GlobalRng::rng);
     Ptr<WeightedMvnModel> mvn;
     Ptr<ScaledChisqModel> wgt;
   };
 
+}  // namespace BOOM
 
-}
 #endif // MVT_MODEL_H
