@@ -37,11 +37,38 @@
 
 namespace BOOM{
 
+  namespace StateSpace {
+    class MultiplexedRegressionData
+        : public Data {
+     public:
+      MultiplexedRegressionData();
+      MultiplexedRegressionData(double y, const Vector &x);
+      MultiplexedRegressionData(const std::vector<Ptr<RegressionData>> &data);
+      MultiplexedRegressionData * clone() const override;
+      std::ostream & display(std::ostream &out) const override;
+      void add_data(Ptr<RegressionData> dp) {regression_data_.push_back(dp);}
+
+      double adjusted_observation(const GlmCoefs &coefficients) const;
+      int sample_size() const {return regression_data_.size();}
+      const RegressionData &regression_data(int i) const;
+      Ptr<RegressionData> regression_data_ptr(int i);
+
+      double state_model_offset() const {return state_model_offset_;}
+      void set_state_model_offset(double offset) {
+        state_model_offset_ = offset;
+      }
+
+     private:
+      std::vector<Ptr<RegressionData>> regression_data_;
+      double state_model_offset_;
+    };
+  }  // namespace StateSpace
+
   // A contemporaneous regression model, where y[t] =
   // beta.dot(X.row(t)) + state space.
   class StateSpaceRegressionModel
       : public StateSpaceModelBase,
-        public IID_DataPolicy<RegressionData>,
+        public IID_DataPolicy<StateSpace::MultiplexedRegressionData>,
         public PriorPolicy
   {
    public:
@@ -86,9 +113,11 @@ namespace BOOM{
     Vector simulate_forecast(const Matrix &newX, const Vector &final_state);
     Vector simulate_forecast(const Matrix &newX);
 
-    // Contribution of the regression model to the overall mean of y
-    // at each time point.
-    Vector regression_contribution()const override;
+    // Contribution of the regression model to the overall mean of y at each
+    // time point.  In the case of multiplexed data, the average regression
+    // contribution for each time point is computed (averaging across
+    // observations with potentially different predictors).
+    Vector regression_contribution() const override;
     bool has_regression() const override {return true;}
 
     // Returns the vector of one-step-ahead prediction errors from a
@@ -103,7 +132,12 @@ namespace BOOM{
     // Need to override add_data so that x's can be shared with the
     // regression model.
     void add_data(Ptr<Data> dp) override;
-    void add_data(Ptr<RegressionData> dp) override;
+
+    // Promotes dp to a MultiplexedRegressionData containing a single
+    // observation, then calls add_data(MultiplexedRegressionData).
+    void add_data(Ptr<RegressionData> dp);
+
+    void add_data(Ptr<StateSpace::MultiplexedRegressionData> dp) override;
 
    private:
     // The regression model holds the regression coefficients and the
