@@ -29,7 +29,7 @@ namespace BOOM{
   PointProcess BoundedPoissonProcessSimulator::simulate(
       const DateTime &t0,
       const DateTime &t1,
-      boost::function<Data*()> mark_generator) const{
+      std::function<Data*()> mark_generator) const{
     PointProcess ans(t0, t1);
     double duration = t1 - t0;
     int number_of_candidate_events = rpois(max_event_rate_ * duration);
