@@ -26,8 +26,7 @@ namespace BOOM{
 
   CPP::CompositeParamPolicy(const CPP &rhs)
     : Model(rhs)
-  { }
-
+  {}
 
   CPP & CPP::operator=(const CompositeParamPolicy &)
   {return *this;}
@@ -37,14 +36,14 @@ namespace BOOM{
   void CPP::add_model(Ptr<Model> m){
     if(have_model(m)) return;
     models_.push_back(m);
-    ParamVector tmp(m->t());
+    ParamVector tmp(m->parameter_vector());
     std::copy(tmp.begin(), tmp.end(), back_inserter(t_));
   }
   void CPP::drop_model(Ptr<Model> m){
     if(!have_model(m)) return;
     models_.erase(std::remove(models_.begin(), models_.end(), m),
                   models_.end());
-    ParamVector tmp(m->t());
+    ParamVector tmp(m->parameter_vector());
     for(uint i = 0; i<tmp.size(); ++i){
       t_.erase(std::remove(t_.begin(), t_.end(), tmp[i]), t_.end());
     }
@@ -54,8 +53,8 @@ namespace BOOM{
     t_.clear();
   }
 
-  ParamVector CPP::t(){return t_;}
-  const ParamVector CPP::t()const{return t_;}
+  ParamVector CPP::parameter_vector(){return t_;}
+  const ParamVector CPP::parameter_vector()const{return t_;}
 
   bool CPP::have_model(Ptr<Model> m)const{
     return std::find(models_.begin(),models_.end(), m)
