@@ -21,9 +21,13 @@
 #include <distributions.hpp>
 #include <Models/SufstatAbstractCombineImpl.hpp>
 
-namespace BOOM{
+namespace BOOM {
+
+  namespace {
+    typedef UniformSuf US;
+    typedef UniformModel UM;
+  }
 
-  typedef UniformSuf US;
   US::UniformSuf()
     : lo_(BOOM::infinity()),
       hi_(BOOM::negative_infinity())
@@ -33,17 +37,17 @@ namespace BOOM{
     : lo_(a),
       hi_(b)
   {
-    assert(a<=b && "Arguments out of order in UniformSuf constructor");
+    assert(a <= b && "Arguments out of order in UniformSuf constructor");
   }
 
-  US::UniformSuf(const std::vector<double> &rhs){
+  US::UniformSuf(const std::vector<double> &rhs) {
     lo_ = rhs[0];
     hi_ = rhs[0];
     uint n = rhs.size();
-    for(uint i=1; i<n; ++i){
+    for (uint i = 1; i < n; ++i) {
       double x = rhs[i];
-      if(x<lo_) lo_ = x;
-      if(x>hi_) hi_ = x;
+      if (x < lo_) lo_ = x;
+      if (x > hi_) hi_ = x;
     }
   }
 
@@ -54,70 +58,68 @@ namespace BOOM{
       hi_(rhs.hi_)
   {}
 
-  US * US::clone()const{return new US(*this);}
+  US * US::clone() const {return new US(*this);}
 
-  void US::clear(){
+  void US::clear() {
     lo_ = BOOM::infinity();
     hi_ = BOOM::negative_infinity();
   }
 
-  void US::update_raw(double x){
+  void US::update_raw(double x) {
     lo_ = x < lo_? x:lo_;
     hi_ = x > hi_? x:hi_;
   }
 
-  void US::Update(const DoubleData &d){ update_raw(d.value()); }
+  void US::Update(const DoubleData &d) { update_raw(d.value()); }
 
-  double US::lo()const{return lo_;}
-  double US::hi()const{return hi_;}
-  void US::set_lo(double a){
+  double US::lo() const {return lo_;}
+  double US::hi() const {return hi_;}
+  void US::set_lo(double a) {
     lo_ = a;
     assert(hi_ >= lo_);
   }
-  void US::set_hi(double b){
+  void US::set_hi(double b) {
     hi_ = b;
     assert(hi_ >= lo_);
   }
 
-  void US::combine(Ptr<US> s){
+  void US::combine(const Ptr<US> &s) {
     lo_ = std::min<double>(lo_, s->lo_);
     hi_ = std::max<double>(hi_, s->hi_);
   }
 
-  void US::combine(const US & s){
+  void US::combine(const US & s) {
     lo_ = std::min<double>(lo_, s.lo_);
     hi_ = std::max<double>(hi_, s.hi_);
   }
 
-  UniformSuf * US::abstract_combine(Sufstat *s){
-    return abstract_combine_impl(this,s); }
+  UniformSuf * US::abstract_combine(Sufstat *s) {
+    return abstract_combine_impl(this, s);
+  }
 
-  Vector US::vectorize(bool)const{
+  Vector US::vectorize(bool) const {
     Vector ans(2);
     ans[0] = lo_;
     ans[1] = hi_;
     return ans;
   }
 
-  Vector::const_iterator US::unvectorize(Vector::const_iterator &v, bool){
+  Vector::const_iterator US::unvectorize(Vector::const_iterator &v, bool) {
     lo_ = *v; ++v;
     hi_ = *v; ++v;
     return v;
   }
 
-  Vector::const_iterator US::unvectorize(const Vector &v, bool minimal){
+  Vector::const_iterator US::unvectorize(const Vector &v, bool minimal) {
     Vector::const_iterator it = v.begin();
     return unvectorize(it, minimal);
   }
 
-  ostream &US::print(ostream &out)const{
+  ostream &US::print(ostream &out) const {
     return out << lo_ << " " << hi_;
   }
 
-  //____________________________________________________________
-
-  typedef UniformModel UM;
-
+  //======================================================================
   UM::UniformModel(double a, double b)
     : ParamPolicy(new UnivParams(a), new UnivParams(b)),
       DataPolicy(new US)
@@ -130,7 +132,6 @@ namespace BOOM{
     mle();
   }
 
-
   UM::UniformModel(const UM &rhs)
     : Model(rhs),
       ParamPolicy(rhs),
@@ -140,56 +141,64 @@ namespace BOOM{
       LoglikeModel(rhs)
   {}
 
+  UM * UM::clone() const {return new UM(*this);}
 
-  UM * UM::clone()const{return new UM(*this);}
+  double UM::lo() const { return LoParam()->value();}
+  double UM::hi() const { return HiParam()->value();}
+  double UM::nc() const { return 1.0/(hi()-lo());}
 
-  double UM::lo()const{ return LoParam()->value();}
-  double UM::hi()const{ return HiParam()->value();}
-  double UM::nc()const{ return 1.0/(hi()-lo());}
-
-  void UM::set_lo(double a){
+  void UM::set_lo(double a) {
     LoParam()->set(a);
-    assert(a<=hi());
+    assert(a <= hi());
   }
-  void UM::set_hi(double b){
+  void UM::set_hi(double b) {
     HiParam()->set(b);
-    assert(b>=lo());
+    assert(b >= lo());
   }
 
-  void UM::set_ab(double a, double b){
-    assert(a<=b);
+  void UM::set_ab(double a, double b) {
+    assert(a <= b);
     LoParam()->set(a);
     HiParam()->set(b);
   }
 
+  double UM::mean() const {
+    return .5 * (lo() + hi());
+  }
 
-  Ptr<UnivParams> UM::LoParam(){return ParamPolicy::prm1();}
-  Ptr<UnivParams> UM::HiParam(){return ParamPolicy::prm2();}
-  const Ptr<UnivParams> UM::LoParam()const{
+  double UM::variance() const {
+    return square(hi() - lo()) / 12.0;
+  }
+
+  Ptr<UnivParams> UM::LoParam() {return ParamPolicy::prm1();}
+  Ptr<UnivParams> UM::HiParam() {return ParamPolicy::prm2();}
+  const Ptr<UnivParams> UM::LoParam() const {
     return ParamPolicy::prm1();}
-  const Ptr<UnivParams> UM::HiParam()const{
+  const Ptr<UnivParams> UM::HiParam() const {
     return ParamPolicy::prm2();}
 
-  double UM::Logp(double x, double &g, double &h, uint nd)const{
-    bool outside = x> hi() || x<lo();
-    if(nd>0){
-      g=0;
-      if(nd>1) h=0; }
+  double UM::Logp(double x, double &g, double &h, uint nd) const {
+    bool outside = x > hi() || x < lo();
+    if (nd > 0) {
+      g = 0;
+      if (nd > 1) h = 0;
+    }
     return outside ? BOOM::negative_infinity() : log(nc());
   }
 
-  double UM::loglike(const Vector &ab)const{
+  double UM::loglike(const Vector &ab) const {
     double lo = ab[0];
     double hi = ab[1];
     bool hi_ok = suf()->hi() <= hi;
     bool lo_ok = suf()->lo() >= lo;
-    if(hi_ok && lo_ok) return log(nc());
+    if (hi_ok && lo_ok) return log(nc());
     return BOOM::negative_infinity();
   }
 
-  void UM::mle(){
+  void UM::mle() {
     set_ab(suf()->lo(), suf()->hi());
   }
 
-  double UM::sim()const{ return runif(lo(), hi()); }
-}
+  double UM::sim() const { return runif(lo(), hi()); }
+
+}  // namespace BOOM
