@@ -10,14 +10,14 @@
 namespace BOOM {
 
   void RListIoManager::add_list_element(RListIoElement *element) {
-    elements_.push_back(boost::shared_ptr<RListIoElement>(element));
+    elements_.push_back(std::shared_ptr<RListIoElement>(element));
   }
 
   SEXP RListIoManager::prepare_to_write(int niter) {
-    SEXP ans;
-    SEXP param_names;
-    PROTECT(ans = Rf_allocVector(VECSXP, elements_.size()));
-    PROTECT(param_names = Rf_allocVector(STRSXP, elements_.size()));
+    RMemoryProtector protector;
+    SEXP ans = protector.protect(Rf_allocVector(VECSXP, elements_.size()));
+    SEXP param_names = protector.protect(
+        Rf_allocVector(STRSXP, elements_.size()));
     for (int i = 0; i < elements_.size(); ++i) {
       SET_VECTOR_ELT(ans, i,
                      elements_[i]->prepare_to_write(niter));
@@ -25,8 +25,6 @@ namespace BOOM {
                      Rf_mkChar(elements_[i]->name().c_str()));
     }
     Rf_namesgets(ans, param_names);
-
-    UNPROTECT(2);
     return ans;
   }
 
@@ -90,10 +88,9 @@ namespace BOOM {
   double * RealValuedRListIoElement::data() { return data_; }
 
   SEXP RealValuedRListIoElement::prepare_to_write(int niter) {
-    SEXP buffer;
-    PROTECT(buffer = Rf_allocVector(REALSXP, niter));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_allocVector(REALSXP, niter));
     StoreBuffer(buffer);
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -108,10 +105,9 @@ namespace BOOM {
   {}
 
   SEXP ListValuedRListIoElement::prepare_to_write(int niter) {
-    SEXP buffer;
-    PROTECT(buffer = Rf_allocVector(VECSXP, niter));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_allocVector(VECSXP, niter));
     StoreBuffer(buffer);
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -198,10 +194,10 @@ namespace BOOM {
       report_error(
           "NULL callback in NativeUnivariateListElement::prepare_to_write");
     }
-    SEXP buffer = PROTECT(Rf_allocVector(REALSXP, niter));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_allocVector(REALSXP, niter));
     StoreBuffer(buffer);
     vector_view_.reset(data(), niter, 1);
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -223,10 +219,12 @@ namespace BOOM {
 
   //======================================================================
   VectorListElement::VectorListElement(Ptr<VectorParams> prm,
-                                       const std::string &name)
+                                       const std::string &name,
+                                       const std::vector<string> &element_names)
       : RealValuedRListIoElement(name),
         prm_(prm),
-        matrix_view_(0, 0, 0)
+        matrix_view_(0, 0, 0),
+        element_names_(element_names)
   {}
 
   SEXP VectorListElement::prepare_to_write(int niter) {
@@ -234,11 +232,14 @@ namespace BOOM {
     // should return the full size, because that's what we're going to
     // write to the R list.
     int dim = prm_->size(false);
+    RMemoryProtector protector;
     SEXP buffer;
-    PROTECT(buffer = Rf_allocMatrix(REALSXP, niter, dim));
+    protector.protect(
+        buffer =
+        SetColnames(Rf_allocMatrix(REALSXP, niter, dim),
+                    element_names_));
     StoreBuffer(buffer);
     matrix_view_.reset(SubMatrix(data(), niter, dim));
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -272,8 +273,9 @@ namespace BOOM {
   }
   //======================================================================
   GlmCoefsListElement::GlmCoefsListElement(Ptr<GlmCoefs> coefs,
-                                           const std::string &param_name)
-      : VectorListElement(coefs, param_name),
+                                           const std::string &param_name,
+                                           const std::vector<string> &element_names)
+      : VectorListElement(coefs, param_name, element_names),
         coefs_(coefs)
   {}
 
@@ -284,35 +286,6 @@ namespace BOOM {
     coefs_->infer_sparsity();
   }
 
-  //======================================================================
-  NamedVectorListElement::NamedVectorListElement(
-      Ptr<VectorParams> prm,
-      const std::string &name,
-      const std::vector<string> &element_names)
-      : VectorListElement(prm, name),
-        element_names_(element_names)
-  {
-    if (prm->dim() != element_names_.size()) {
-      std::ostringstream err;
-      err << "Wrong number of names (" << element_names_.size()
-          << ") supplied to NamedVectorListElement of dimension "
-          << prm->dim() << ".";
-      report_error(err.str().c_str());
-    }
-  }
-
-  SEXP NamedVectorListElement::prepare_to_write(int niter) {
-    SEXP buffer;
-    PROTECT(buffer = VectorListElement::prepare_to_write(niter));
-    SEXP r_dimnames;
-    PROTECT(r_dimnames = Rf_allocVector(VECSXP, 2));
-    SET_VECTOR_ELT(r_dimnames, 0, R_NilValue);
-    SET_VECTOR_ELT(r_dimnames, 1, CharacterVector(element_names_));
-    Rf_dimnamesgets(buffer, r_dimnames);
-    UNPROTECT(2);
-    return buffer;
-  }
-
   //======================================================================
   SdVectorListElement::SdVectorListElement(Ptr<VectorParams> prm,
                                            const std::string &name)
@@ -323,11 +296,10 @@ namespace BOOM {
 
   SEXP SdVectorListElement::prepare_to_write(int niter) {
     int dim = prm_->size();
-    SEXP buffer;
-    PROTECT(buffer = Rf_allocMatrix(REALSXP, niter, dim));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_allocMatrix(REALSXP, niter, dim));
     StoreBuffer(buffer);
     matrix_view_.reset(SubMatrix(data(), niter, dim));
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -383,8 +355,8 @@ namespace BOOM {
 
   void MatrixListElementBase::set_buffer_dimnames(SEXP buffer) {
     // Set the dimnames on the buffer
-    SEXP r_dimnames;
-    PROTECT(r_dimnames = Rf_allocVector(VECSXP, 3));
+    RMemoryProtector protector;
+    SEXP r_dimnames = protector.protect(Rf_allocVector(VECSXP, 3));
     // The leading dimension (MCMC iteration number) does not get
     // names.
     SET_VECTOR_ELT(r_dimnames, 0, R_NilValue);
@@ -407,7 +379,6 @@ namespace BOOM {
       SET_VECTOR_ELT(r_dimnames, 2, R_NilValue);
     }
     Rf_dimnamesgets(buffer, r_dimnames);
-    UNPROTECT(1);  // r_dimnames
   }
 
   //======================================================================
@@ -422,12 +393,11 @@ namespace BOOM {
   SEXP MatrixListElement::prepare_to_write(int niter) {
     int nr = prm_->nrow();
     int nc = prm_->ncol();
-    SEXP buffer;
-    PROTECT(buffer = Rf_alloc3DArray(REALSXP, niter, nr, nc));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_alloc3DArray(REALSXP, niter, nr, nc));
     set_buffer_dimnames(buffer);
     StoreBuffer(buffer);
     array_view_.reset(data(), Array::index3(niter, nr, nc));
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -446,11 +416,10 @@ namespace BOOM {
 
   void MatrixListElement::prepare_to_stream(SEXP object) {
     RealValuedRListIoElement::prepare_to_stream(object);
-    SEXP r_array_dims;
-    PROTECT(r_array_dims = Rf_getAttrib(rbuffer(), R_DimSymbol));
+    RMemoryProtector protector;
+    SEXP r_array_dims = protector.protect(Rf_getAttrib(rbuffer(), R_DimSymbol));
     int * array_dims = INTEGER(r_array_dims);
     array_view_.reset(data(), std::vector<int>(array_dims, array_dims + 3));
-    UNPROTECT(1);
   }
 
   void MatrixListElement::stream() {
@@ -509,7 +478,7 @@ namespace BOOM {
         array_view_(0, Array::index3(0, 0, 0))
   {}
 
-  void HierarchicalVectorListElement::add_vector(Ptr<VectorParams> v) {
+  void HierarchicalVectorListElement::add_vector(const Ptr<VectorParams> &v) {
     if (!v) {
       report_error("Null pointer passed to HierarchicalVectorListElement");
     }
@@ -526,21 +495,20 @@ namespace BOOM {
   SEXP HierarchicalVectorListElement::prepare_to_write(int niter) {
     int number_of_groups = parameters_.size();
     int dim = parameters_[0]->dim();
-    SEXP buffer;
-    PROTECT(buffer = Rf_alloc3DArray(REALSXP, niter, number_of_groups, dim));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_alloc3DArray(
+        REALSXP, niter, number_of_groups, dim));
     StoreBuffer(buffer);
     array_view_.reset(data(), Array::index3(niter, number_of_groups, dim));
-    UNPROTECT(1);
     return buffer;
   }
 
   void HierarchicalVectorListElement::prepare_to_stream(SEXP object) {
     RealValuedRListIoElement::prepare_to_stream(object);
-    SEXP r_array_dims;
-    PROTECT(r_array_dims = Rf_getAttrib(rbuffer(), R_DimSymbol));
+    RMemoryProtector protector;
+    SEXP r_array_dims = protector.protect(Rf_getAttrib(rbuffer(), R_DimSymbol));
     int * array_dims = INTEGER(r_array_dims);
     array_view_.reset(data(), std::vector<int>(array_dims, array_dims + 3));
-    UNPROTECT(1);
   }
 
   void HierarchicalVectorListElement::write() {
@@ -594,11 +562,10 @@ namespace BOOM {
 
   SEXP SpdListElement::prepare_to_write(int niter) {
     int dim = prm_->dim();
-    SEXP buffer;
-    PROTECT(buffer = Rf_alloc3DArray(REALSXP, niter, dim, dim));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_alloc3DArray(REALSXP, niter, dim, dim));
     StoreBuffer(buffer);
     array_view_.reset(data(), Array::index3(niter, dim, dim));
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -617,11 +584,10 @@ namespace BOOM {
 
   void SpdListElement::prepare_to_stream(SEXP object) {
     RealValuedRListIoElement::prepare_to_stream(object);
-    SEXP r_array_dims;
-    PROTECT(r_array_dims = Rf_getAttrib(rbuffer(), R_DimSymbol));
+    RMemoryProtector protector;
+    SEXP r_array_dims = protector.protect(Rf_getAttrib(rbuffer(), R_DimSymbol));
     int * array_dims = INTEGER(r_array_dims);
     array_view_.reset(data(), std::vector<int>(array_dims, array_dims + 3));
-    UNPROTECT(1);
   }
 
   void SpdListElement::stream() {
@@ -683,14 +649,14 @@ namespace BOOM {
           "NULL callback in NativeVectorListElement::prepare_to_write");
     }
     int dim = callback_->dim();
-    SEXP buffer = PROTECT(Rf_allocMatrix(REALSXP, niter, dim));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(Rf_allocMatrix(REALSXP, niter, dim));
     StoreBuffer(buffer);
     matrix_view_.reset(SubMatrix(data(), niter, dim));
     if (matrix_view_.ncol() != callback_->dim()) {
       report_error(
           "wrong size buffer set up for NativeVectorListElement::write");
     }
-    UNPROTECT(1);
     return buffer;
   }
 
@@ -729,28 +695,26 @@ namespace BOOM {
       report_error(
           "NULL callback in NativeMatrixListElement::prepare_to_write.");
     }
-    SEXP buffer = PROTECT(Rf_alloc3DArray(REALSXP,
-                                          niter,
-                                          callback_->nrow(),
-                                          callback_->ncol()));
+    RMemoryProtector protector;
+    SEXP buffer = protector.protect(
+        Rf_alloc3DArray(REALSXP, niter, callback_->nrow(), callback_->ncol()));
     set_buffer_dimnames(buffer);
     StoreBuffer(buffer);
     array_view_.reset(data(),
                       Array::index3(niter,
                                     callback_->nrow(),
                                     callback_->ncol()));
-    UNPROTECT(1);
     return buffer;
   }
 
   void NativeMatrixListElement::prepare_to_stream(SEXP object) {
     if (!streaming_buffer_) return;
     RealValuedRListIoElement::prepare_to_stream(object);
-    SEXP r_array_dims = PROTECT(Rf_getAttrib(rbuffer(), R_DimSymbol));
+    RMemoryProtector protector;
+    SEXP r_array_dims = protector.protect(Rf_getAttrib(rbuffer(), R_DimSymbol));
     int *array_dims(INTEGER(r_array_dims));
     std::vector<int> dims(array_dims, array_dims + 3);
     array_view_.reset(data(), dims);
-    UNPROTECT(1);
   }
 
   void NativeMatrixListElement::write() {
@@ -798,22 +762,20 @@ namespace BOOM {
     std::vector<int> array_dims(dims.size() + 1);
     array_dims[0] = niter;
     std::copy(dims.begin(), dims.end(), array_dims.begin() + 1);
-
-    SEXP r_array_dimensions;
-    PROTECT(r_array_dimensions = Rf_allocVector(INTSXP, array_dims.size()));
+    RMemoryProtector protector;
+    SEXP r_array_dimensions =protector.protect(Rf_allocVector(
+        INTSXP, array_dims.size()));
     int * rdims = INTEGER(r_array_dimensions);
     for (int i = 0; i < array_dims.size(); ++i) {
       rdims[i] = array_dims[i];
     }
 
-    SEXP r_buffer;
-    PROTECT(r_buffer = Rf_allocArray(REALSXP, r_array_dimensions));
+    SEXP r_buffer = protector.protect(Rf_allocArray(
+        REALSXP, r_array_dimensions));
     StoreBuffer(r_buffer);
 
     array_buffer_.reset(REAL(r_buffer), array_dims);
     array_view_index_.assign(array_dims.size(), -1);
-
-    UNPROTECT(2);
     return r_buffer;
   }
 
